---
name: feature request
about: suggest an idea to implement
title: "[FEAT]"
labels: feature-request
assignees: ''

---

<!--make sure you have checked issue #4 before requesting!-->

### is your request due to an existing bug?
a clear and concise description of what the problem is that you are facing, and wanting to fix

### describe the solution you'd like
a clear and concise description of what you want to happen.

### describe any alternatives you've considered
a clear and concise description of any alternative solutions or features you've considered.

### are there any other file managers that have this feature
list the file explorers that may have the features that you are looking for

### Additional context
add any other context or screenshots about the feature request here.
